# File: CarolinaEstuaries.R
# Purpose: Estimation for South Carolina Estuaries
# Programmers: Tony Olsen and Tom Kincaid
# Date: October 27, 2006


# Load the spsurvey library

library(spsurvey)

# Read the data file

SCestuarydata <- read.delim("SCestuarydata.tab")
cat("The initial six lines in the data file follow:\n\n")
print(head(SCestuarydata))

# Print a table displaying the count for each code for EE.Status - Site
#    Evaluation status
# The meaning for each code follows:
#    TS - target and sampled site
#    NT - site was non-target (dry, too shallow, ...)
#    NN - site not needed (not evaluated)

cat("\nA table displaying the number of values for each level of the site status variable follows:\n")
print(table(SCestuarydata$EE.Status))


# Conduct an analysis of IBI status and WQ status

# Create the sites data frame, which identifies sites to use in the analysis
# Note that only Target (TS) sites are used

sites <- data.frame(siteID=SCestuarydata$Site.id,
                    Use=SCestuarydata$EE.Status == "TS")

# Create the subpop data frame, which defines populations and subpopulations for
#    which estimates are desired

subpop <- data.frame(siteID=SCestuarydata$Site.id,
                     EstuaryType=SCestuarydata$Type)

# Create the design data frame, which identifies the stratum code, weight,
#    x-coordinate, and y-coordinate for each site ID

design <- data.frame(siteID=SCestuarydata$Site.id,
                     stratum=SCestuarydata$Stratum,
                     wgt=SCestuarydata$final.wt,
                     xcoord=SCestuarydata$xmarinus,
                     ycoord=SCestuarydata$ymarinus)

# Create the data.cat data frame, which specifies the variables to use in the
#    analysis

data.cat <- data.frame(siteID=SCestuarydata$Site.id,
                       IBIStatus=SCestuarydata$IBI.Status,
                       WQStatus=SCestuarydata$WQ.Status)

# Produce estimates for the IBI status and WQ status variables
# Note that the size of the target estuary area is not known, so argument
#    popsize is not specified

ConditionSum <- cat.analysis(sites, subpop, design, data.cat)

# Write results as a csv file to read into a spreadsheet

write.table(ConditionSum, file="ConditionSum.csv", sep=",", row.names=FALSE)


# Conduct an analysis of IBI score and WQ score

# Note that the existing sites, subpop, and design data frames can be used

# Create the data.cont data frame

data.cont <- data.frame(siteID=SCestuarydata$Site.id,
                        IBIScore=SCestuarydata$EE.IBI,
                        WQScore=SCestuarydata$WQ.IS)

ScoresSum <- cont.analysis(sites, subpop, design, data.cont)

# Write results as csv files to read in spreadsheets

write.table(ScoresSum$CDF, file="ScoresSumCDF.csv", sep=",", row.names=FALSE)
write.table(ScoresSum$Pct, file="ScoresSumPct.csv", sep=",", row.names=FALSE)
